sdv.metadata.table.Table
========================

.. currentmodule:: sdv.metadata.table

.. autoclass:: Table

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Table.__init__
      ~Table.filter_valid
      ~Table.fit
      ~Table.from_dict
      ~Table.from_json
      ~Table.get_dtypes
      ~Table.get_fields
      ~Table.get_model_kwargs
      ~Table.make_ids_unique
      ~Table.reverse_transform
      ~Table.set_model_kwargs
      ~Table.set_primary_key
      ~Table.to_dict
      ~Table.to_json
      ~Table.transform
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Table.fitted
   
   